@@ -31,7 +31,6 @@ TYPE_INFO_DICT = {
     "duolingo": "Duolingo",
     "github": "GitHub",
     "leetcode": "LeetCode",
-    "twitter": "Twitter",
     "youtube": "YouTube",
     "gitlab": "GitLab",
     "bilibili": "bilibili",
@@ -48,4 +47,6 @@ TYPE_INFO_DICT = {
     "covid": "COVID-19",
     "todoist": "Todoist",
     "apple": "AppleHealth",
+    "chatgpt": "ChatGPT",
+    "neodb": "NeoDB",
 }
