@@ -2,7 +2,7 @@ import pendulum
 import requests
 
 from github_poster.loader.base_loader import BaseLoader
-from github_poster.loader.config import DUOLINGO_CALENDAR_API, DUOLINGO_LOGIN_URL
+from github_poster.loader.config import DUOLINGO_CALENDAR_API
 
 
 class DuolingoLoader(BaseLoader):
@@ -11,15 +11,13 @@ class DuolingoLoader(BaseLoader):
 
     def __init__(self, from_year, to_year, _type, **kwargs):
         super().__init__(from_year, to_year, _type)
-        self.user_name = kwargs.get("duolingo_user_name", "")
-        self.password = kwargs.get("duolingo_password", "")
+        self.duolingo_user_name = kwargs.get("duolingo_user_name", "")
+        self.duolingo_jwt = kwargs.get("duolingo_jwt", "")
         self.session = requests.Session()
         self.headers = {
             "Accept": "*/*",
             "User-Agent": "request",
         }
-        # duolingo name to get the calendar
-        self.duolingo_id = ""
 
     @classmethod
     def add_loader_arguments(cls, parser, optional):
@@ -31,22 +29,19 @@ class DuolingoLoader(BaseLoader):
             required=optional,
         )
         parser.add_argument(
-            "--duolingo_password",
-            dest="duolingo_password",
+            "--duolingo_jwt",
+            dest="duolingo_jwt",
             type=str,
-            help="",
+            help="use `document.cookie.match(new RegExp('(^| )jwt_token=([^;]+)'))[0].slice(11)` in console",
             required=optional,
         )
 
     def login(self):
-        r = self.session.post(
-            DUOLINGO_LOGIN_URL,
-            params={"login": self.user_name, "password": self.password},
+        self.headers["Authorization"] = "Bearer " + self.duolingo_jwt
+        self.duolingo_id = self.session.get(
+            f"https://www.duolingo.com/users/{self.duolingo_user_name}",
             headers=self.headers,
-        )
-        if r.status_code != 200:
-            raise Exception("Login failed")
-        self.duolingo_id = r.json()["user_id"]
+        ).json()["id"]
 
     def get_api_data(self):
         month_list = self.make_month_list()
